# API Reference

## bcsophyd.zmq

The main module containing all BCS-ZMQ integration classes.

### BCSServer

```{eval-rst}
.. autoclass:: bcsophyd.zmq.bcs_server.BCSServer
   :members:
   :undoc-members:
   :show-inheritance:
```

### BCSDeviceManager

```{eval-rst}
.. autoclass:: bcsophyd.zmq.bcs_device_manager.BCSDeviceManager
   :members:
   :undoc-members:
   :show-inheritance:
```

### BCSMotor

```{eval-rst}
.. autoclass:: bcsophyd.zmq.bcs_motor.BCSMotor
   :members:
   :undoc-members:
   :show-inheritance:
```

### BCSSignal

```{eval-rst}
.. autoclass:: bcsophyd.zmq.bcs_signal.BCSSignal
   :members:
   :undoc-members:
   :show-inheritance:
```

### BCSAreaDetector

```{eval-rst}
.. autoclass:: bcsophyd.zmq.bcs_area_detector.BCSAreaDetector
   :members:
   :undoc-members:
   :show-inheritance:
```

## Helper Classes

### MotorStatus

```{eval-rst}
.. autoclass:: bcsophyd.zmq.bcs_server.MotorStatus
   :members:
   :undoc-members:
   :show-inheritance:
```
